@@ -78,8 +78,9 @@ void WEntry::SetValid(GtkEntry *entry, bool valid) {
 	gtk_widget_set_name(GTK_WIDGET(entry), valid ? "" : "entryInvalid");
 #else
 	if (valid) {
-		GdkColor white = { 0, 0xFFFF, 0xFFFF, 0xFFFF};
-		gtk_widget_modify_base(GTK_WIDGET(entry), GTK_STATE_NORMAL, &white);
+		// Reset widget's background color
+		// to the one given by the GTK theme
+		gtk_widget_modify_base(GTK_WIDGET(entry), GTK_STATE_NORMAL, NULL);
 	} else {
 		GdkColor red = { 0, 0xFFFF, 0x6666, 0x6666 };
 		gtk_widget_modify_base(GTK_WIDGET(entry), GTK_STATE_NORMAL, &red);
@@ -361,7 +362,7 @@ gboolean WCheckDraw::Draw(GtkWidget *widget, cairo_t *cr) {
 			cr,
 			state,
 			shadow,
-			widget, const_cast<char *>("button"),
+			widget, "button",
 			0, 0,
 			allocation.width, allocation.height);
 #endif
@@ -376,7 +377,7 @@ gboolean WCheckDraw::Draw(GtkWidget *widget, cairo_t *cr) {
 		gtk_paint_focus(pStyle,
 			cr,
 			state,
-			widget, const_cast<char *>("button"),
+			widget, "button",
 			2, 2,
 			allocation.width-4, allocation.height-4);
 #endif
@@ -441,14 +442,14 @@ gboolean WCheckDraw::Expose(GtkWidget *widget, GdkEventExpose */*event*/) {
 		gtk_paint_box(pStyle, widget->window,
 			       state,
 			       shadow,
-			       &area, widget, const_cast<char *>("button"),
+			       &area, widget, "button",
 			       0, 0,
 			       area.width, area.height);
 	if (HasFocus()) {
 		// Draw focus inset by 2 pixels
 		gtk_paint_focus(pStyle, widget->window,
 			       state,
-			       &area, widget, const_cast<char *>("button"),
+			       &area, widget, "button",
 			       2, 2,
 			       area.width-4, area.height-4);
 	}
